package com.jjt.rz.service;

import java.util.List;
import com.jjt.rz.domain.TwinDeviceRz;

/**
 * 染整线设备管理Service接口
 *
 * @author wukai
 * @date 2025-05-21
 */
public interface ITwinDeviceRzService {
    /**
     * 查询染整线设备管理
     *
     * @param deviceId 染整线设备管理主键
     * @return 染整线设备管理
     */
    public TwinDeviceRz selectTwinDeviceRzByDeviceId(Long deviceId);

    /**
     * 查询染整线设备管理列表
     *
     * @param twinDeviceRz 染整线设备管理
     * @return 染整线设备管理集合
     */
    public List<TwinDeviceRz> selectTwinDeviceRzList(TwinDeviceRz twinDeviceRz);

    /**
     * 新增染整线设备管理
     *
     * @param twinDeviceRz 染整线设备管理
     * @return 结果
     */
    public int insertTwinDeviceRz(TwinDeviceRz twinDeviceRz);

    /**
     * 修改染整线设备管理
     *
     * @param twinDeviceRz 染整线设备管理
     * @return 结果
     */
    public int updateTwinDeviceRz(TwinDeviceRz twinDeviceRz);

    /**
     * 批量删除染整线设备管理
     *
     * @param deviceIds 需要删除的染整线设备管理主键集合
     * @return 结果
     */
    public int deleteTwinDeviceRzByDeviceIds(Long[] deviceIds);

    /**
     * 删除染整线设备管理信息
     *
     * @param deviceId 染整线设备管理主键
     * @return 结果
     */
    public int deleteTwinDeviceRzByDeviceId(Long deviceId);
}
